@@ -62,19 +62,19 @@ namespace ConstraintTypes {
             static Constraint* createNew(ConstraintNode*);
             static ConstraintFactoryEntry* registerMe();
 
-            virtual QWidget* editWidget() const;
-            virtual void toXml(QDomDocument&, QDomElement&) const;
+            QWidget* editWidget() const override;
+            void toXml(QDomDocument&, QDomElement&) const override;
 
-            virtual QString getName() const;
+            QString getName() const override;
 
-            virtual Collections::QueryMaker* initQueryMaker(Collections::QueryMaker*) const;
-            virtual double satisfaction(const Meta::TrackList&) const;
+            Collections::QueryMaker* initQueryMaker(Collections::QueryMaker*) const override;
+            double satisfaction(const Meta::TrackList&) const override;
 
             // Implementation of MatchingConstraint virtuals
-            const QBitArray whatTracksMatch( const Meta::TrackList& );
-            int constraintMatchType() const;
+            const QBitArray whatTracksMatch( const Meta::TrackList& ) override;
+            int constraintMatchType() const override;
 
-        private slots:
+        private Q_SLOTS:
             void setComparison( int );
             void setField( const QString& );
             void setInvert( bool );
@@ -83,8 +83,8 @@ namespace ConstraintTypes {
 
         private:
             TagMatch( QDomElement&, ConstraintNode* );
-            TagMatch( ConstraintNode* );
-            ~TagMatch();
+            explicit TagMatch( ConstraintNode* );
+            ~TagMatch() override;
 
             // constraint parameters
             int m_comparison;
@@ -114,7 +114,7 @@ namespace ConstraintTypes {
                 double compareNum( const double, const int, const double, const double, const qint64 ) const;
                 double compareStr( const QString&, const int, const QString& ) const;
                 double compareDate( const uint, const int, const QVariant&, const double ) const;
-                double compareLabels( const Meta::TrackPtr, const int, const QString& ) const;
+                double compareLabels( const Meta::TrackPtr&, const int, const QString& ) const;
 
                 // rough inverses of the comparison
                 uint rangeDate( const double ) const;
@@ -135,11 +135,11 @@ namespace ConstraintTypes {
 
         public:
             TagMatchFieldsModel();
-            ~TagMatchFieldsModel();
+            ~TagMatchFieldsModel() override;
 
             // required by QAbstractListModel
-            QVariant data( const QModelIndex&, int role = Qt::DisplayRole ) const;
-            int rowCount( const QModelIndex& parent = QModelIndex() ) const;
+            QVariant data( const QModelIndex&, int role = Qt::DisplayRole ) const override;
+            int rowCount( const QModelIndex& parent = QModelIndex() ) const override;
 
             bool contains( const QString& ) const;
             int index_of( const QString& ) const;
@@ -162,7 +162,7 @@ namespace ConstraintTypes {
             TagMatchEditWidget( const int, const QString&, const bool, const int, const QVariant& );
             ~TagMatchEditWidget();
 
-        signals:
+        Q_SIGNALS:
             void comparisonChanged( int );
             void fieldChanged( const QString& );
             void invertChanged( bool );
@@ -170,7 +170,7 @@ namespace ConstraintTypes {
             void valueChanged( const QVariant& );
             void updated();
 
-        private slots:
+        private Q_SLOTS:
             // comparison
             void on_comboBox_ComparisonDate_currentIndexChanged( int );
             void on_comboBox_ComparisonInt_currentIndexChanged( int );
