@@ -20,11 +20,8 @@
 #include "core/transcoding/TranscodingController.h"
 
 #include <QIcon>
-#include <QPushButton>
-
-#include <KConfigGroup>
 #include <QDialogButtonBox>
-#include <QVBoxLayout>
+#include <QPushButton>
 
 using namespace Transcoding;
 
@@ -135,7 +132,7 @@ AssistantDialog::populateFormatList()
     ui.groupBox->setEnabled( !available.isEmpty() );
     ui.encoderNotFoundLabel->setVisible( available.isEmpty() );
 
-    foreach( Encoder encoder, Amarok::Components::transcodingController()->allEncoders() )
+    for( Encoder encoder : Amarok::Components::transcodingController()->allEncoders() )
     {
         if( encoder == INVALID || encoder == JUST_COPY )
             continue; // skip "fake" encoders
